@@ -151,7 +151,8 @@
      ("(\\<\\(helm-awhile\\)\\>" 1 font-lock-keyword-face)
      ("(\\<\\(helm-acond\\)\\>" 1 font-lock-keyword-face)
      ("(\\<\\(helm-aand\\)\\>" 1 font-lock-keyword-face)
-     ("(\\<\\(helm-with-gensyms\\)\\>" 1 font-lock-keyword-face))))
+     ("(\\<\\(helm-with-gensyms\\)\\>" 1 font-lock-keyword-face)
+     ("(\\<\\(helm-read-answer\\)\\>" 1 font-lock-keyword-face))))
 
 
 ;;; Load the autoload file
