@@ -35,6 +35,10 @@
 (declare-function org-content "org.el")
 (declare-function org-mark-ring-goto "org.el")
 (declare-function org-mark-ring-push "org.el")
+(declare-function helm-interpret-value "helm.el")
+(declare-function helm-get-current-source "helm.el")
+(defvar helm-sources)
+(defvar helm-initial-frame)
 (defvar helm-current-position)
 (defvar wdired-old-marks)
 (defvar helm-persistent-action-display-window)
